summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/matrix/MatrixView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/matrix/MatrixView.h')
-rw-r--r--src/gui/editors/matrix/MatrixView.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/src/gui/editors/matrix/MatrixView.h b/src/gui/editors/matrix/MatrixView.h
index 49e0358..0951c8c 100644
--- a/src/gui/editors/matrix/MatrixView.h
+++ b/src/gui/editors/matrix/MatrixView.h
@@ -35,20 +35,20 @@
#include "MatrixVLayout.h"
#include "MatrixCanvasView.h"
#include <kdockwidget.h>
-#include <qpoint.h>
-#include <qsize.h>
+#include <tqpoint.h>
+#include <tqsize.h>
#include <vector>
#include "base/Event.h"
#include "document/ConfigGroups.h"
-class QWidget;
-class QPaintEvent;
-class QObject;
-class QMouseEvent;
-class QLabel;
-class QCursor;
-class QCanvas;
+class TQWidget;
+class TQPaintEvent;
+class TQObject;
+class TQMouseEvent;
+class TQLabel;
+class TQCursor;
+class TQCanvas;
class KComboBox;
@@ -88,7 +88,7 @@ class MatrixView : public EditView
public:
MatrixView(RosegardenGUIDoc *doc,
std::vector<Segment *> segments,
- QWidget *parent, bool drumMode);
+ TQWidget *parent, bool drumMode);
virtual ~MatrixView();
@@ -100,9 +100,9 @@ public:
timeT startTime = 0,
timeT endTime = 0);
- QCanvas* canvas() { return getCanvasView()->canvas(); }
+ TQCanvas* canvas() { return getCanvasView()->canvas(); }
- void setCanvasCursor(const QCursor &cursor) {
+ void setCanvasCursor(const TQCursor &cursor) {
getCanvasView()->viewport()->setCursor(cursor);
}
@@ -194,7 +194,7 @@ public:
double getXbyInverseWorldMatrix(double value)
{ return m_canvasView->inverseWorldMatrix().m11() * value; }
- QPoint inverseMapPoint(const QPoint& p) { return m_canvasView->inverseMapPoint(p); }
+ TQPoint inverseMapPoint(const TQPoint& p) { return m_canvasView->inverseMapPoint(p); }
/*
* Repaint the control rulers
@@ -240,7 +240,7 @@ signals:
void jumpPlaybackTo(timeT);
void panic();
- void stepByStepTargetRequested(QObject *);
+ void stepByStepTargetRequested(TQObject *);
void editTriggerSegment(int);
@@ -316,10 +316,10 @@ public slots:
* or somewhere on the staff
*/
void slotMousePressed(timeT time, int pitch,
- QMouseEvent*, MatrixElement*);
+ TQMouseEvent*, MatrixElement*);
- void slotMouseMoved(timeT time, int pitch, QMouseEvent*);
- void slotMouseReleased(timeT time, int pitch, QMouseEvent*);
+ void slotMouseMoved(timeT time, int pitch, TQMouseEvent*);
+ void slotMouseReleased(timeT time, int pitch, TQMouseEvent*);
/**
* Called when the mouse cursor moves over a different height on
@@ -468,8 +468,8 @@ public slots:
/// Note-on or note-off received asynchronously -- as above
void slotInsertableNoteEventReceived(int pitch, int velocity, bool noteOn);
- /// The given QObject has originated a step-by-step-editing request
- void slotStepByStepTargetRequested(QObject *);
+ /// The given TQObject has originated a step-by-step-editing request
+ void slotStepByStepTargetRequested(TQObject *);
void slotInstrumentLevelsChanged(InstrumentId,
const LevelInfo &);
@@ -506,7 +506,7 @@ protected slots:
*/
void slotCheckTrackAssignments();
- void slotToolHelpChanged(const QString &);
+ void slotToolHelpChanged(const TQString &);
void slotMouseEnteredCanvasView();
void slotMouseLeftCanvasView();
@@ -547,12 +547,12 @@ protected:
/**
* Return the size of the MatrixCanvasView
*/
- virtual QSize getViewSize();
+ virtual TQSize getViewSize();
/**
* Set the size of the MatrixCanvasView
*/
- virtual void setViewSize(QSize);
+ virtual void setViewSize(TQSize);
virtual MatrixCanvasView *getCanvasView();
@@ -571,7 +571,7 @@ protected:
*/
bool canPreviewAnotherNote();
- virtual void paintEvent(QPaintEvent* e);
+ virtual void paintEvent(TQPaintEvent* e);
virtual void updateViewCaption();
@@ -600,10 +600,10 @@ protected:
timeT m_lastEndMarkerTime;
// Status bar elements
- QLabel* m_hoveredOverAbsoluteTime;
- QLabel* m_hoveredOverNoteName;
- QLabel *m_selectionCounter;
- QLabel *m_insertModeLabel;
+ TQLabel* m_hoveredOverAbsoluteTime;
+ TQLabel* m_hoveredOverNoteName;
+ TQLabel *m_selectionCounter;
+ TQLabel *m_insertModeLabel;
bool m_haveHoveredOverNote;
/**
@@ -642,7 +642,7 @@ protected:
KComboBox *m_snapGridCombo;
ZoomSlider<double> *m_hZoomSlider;
ZoomSlider<double> *m_vZoomSlider;
- QLabel *m_zoomLabel;
+ TQLabel *m_zoomLabel;
// Hold our matrix quantization values and snap values
//
@@ -652,7 +652,7 @@ protected:
std::vector<std::pair<PropertyViewRuler*, PropertyBox*> > m_propertyViewRulers;
ChordNameRuler *m_chordNameRuler;
- QWidget *m_tempoRuler;
+ TQWidget *m_tempoRuler;
// ruler used to scale tempo and chord name ruler
ZoomableMatrixHLayoutRulerScale* m_referenceRuler;
@@ -664,7 +664,7 @@ protected:
bool m_drumMode;
bool m_mouseInCanvasView;
- QString m_toolContextHelp;
+ TQString m_toolContextHelp;
};
// Commented this out - was a MatrixView inner class, but we get a warning